@@ -256,7 +256,7 @@ class HTMLReportCreator:
             authors_in_month = raw_authors_data.loc[yymm]
             project_data['months'].append({
                 'date': yymm,
-                'top_author': {'name': authors_in_month.index[0], 'commits_count': authors_in_month[0]},
+                'top_author': {'name': authors_in_month.index[0], 'commits_count': authors_in_month.iloc[0]},
                 'next_top_authors': ', '.join(list(authors_in_month.index[1:5])),
                 'all_commits_count': authors_in_month.sum(),
                 'total_authors_count': authors_in_month.size
@@ -270,7 +270,7 @@ class HTMLReportCreator:
             authors_in_year = raw_authors_data.loc[y]
             project_data['years'].append({
                 'date': y,
-                'top_author': {'name': authors_in_year.index[0], 'commits_count': authors_in_year[0]},
+                'top_author': {'name': authors_in_year.index[0], 'commits_count': authors_in_year.iloc[0]},
                 'next_top_authors': ', '.join(list(authors_in_year.index[1:max_top_authors_index])),
                 'all_commits_count': authors_in_year.sum(),
                 'total_authors_count': authors_in_year.size
@@ -337,8 +337,10 @@ class HTMLReportCreator:
             # limit to only top authors
             if sorted_contribution.shape[0] > max_authors_per_plot_count + 1:
                 rest_contributions = sorted_contribution[max_authors_per_plot_count:].sum()
-                sorted_contribution = sorted_contribution[:max_authors_per_plot_count] \
-                    .append(pd.Series(rest_contributions, index=["others"]))
+                sorted_contribution = sorted_contribution[:max_authors_per_plot_count]
+                # at this point index is a CategoricalIndex and without next line cannot accept new category: "others"
+                sorted_contribution.index = sorted_contribution.index.to_list()
+                sorted_contribution = sorted_contribution.append(pd.Series(rest_contributions, index=["others"]))
             sorted_contribution = sorted_contribution.to_dict(OrderedDict)
             # Contribution plot data
             contribution = {
